==> webkitgtk_2.4.11.orig.tar.xz: webkitgtk-2.4.11/Source/WebCore/platform/LengthSize.h <==
/*
    Copyright (C) 1999 Lars Knoll (knoll@kde.org)
    Copyright (C) 2006, 2008 Apple Inc. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef LengthSize_h
#define LengthSize_h

#include "FloatSize.h"
#include "Length.h"

namespace WebCore {

struct LengthSize {
public:
    LengthSize()
    {
    }
    
    LengthSize(Length width, Length height)
        : m_width(std::move(width))
        , m_height(std::move(height))
    {
    }

    bool operator==(const LengthSize& o) const
    {
        return m_width == o.m_width && m_height == o.m_height;
    }

    void setWidth(Length width) { m_width = std::move(width); }
    const Length& width() const { return m_width; }

    void setHeight(Length height) { m_height = std::move(height); }
    const Length& height() const { return m_height; }

    LengthSize blend(const LengthSize& from, double progress) const
    {
        return LengthSize(m_width.blend(from.width(), progress), m_height.blend(from.height(), progress));
    }

    FloatSize floatSize() const
    {
        return FloatSize(m_width.value(), m_height.value());
    }

private:
    Length m_width;
    Length m_height;
};

} // namespace WebCore

#endif // LengthSize_h

==> webkitgtk-2.14.5.tar.xz: webkitgtk-2.14.5/Source/WebCore/platform/LengthSize.h <==
/*
    Copyright (C) 1999 Lars Knoll (knoll@kde.org)
    Copyright (C) 2006, 2008 Apple Inc. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef LengthSize_h
#define LengthSize_h

#include "Length.h"

namespace WebCore {

struct LengthSize {
public:
    LengthSize()
    {
    }
    
    LengthSize(Length width, Length height)
        : m_width(WTFMove(width))
        , m_height(WTFMove(height))
    {
    }

    bool operator==(const LengthSize& o) const
    {
        return m_width == o.m_width && m_height == o.m_height;
    }

    void setWidth(Length width) { m_width = WTFMove(width); }
    const Length& width() const { return m_width; }

    void setHeight(Length height) { m_height = WTFMove(height); }
    const Length& height() const { return m_height; }

private:
    Length m_width;
    Length m_height;
};

inline LengthSize blend(const LengthSize& from, const LengthSize& to, double progress)
{
    return LengthSize(blend(from.width(), to.width(), progress), blend(from.height(), to.height(), progress));
}

TextStream& operator<<(TextStream&, const LengthSize&);

} // namespace WebCore

#endif // LengthSize_h
